@@ -20,6 +20,7 @@ from pathlib2 import Path as Path2
 
 from numpy.lib.function_base import iterable
 from matplotlib.backends.backend_agg import FigureCanvasAgg
+from .array_processing import get_Several_MinMax_Array
 
 
 popular_image_suffixes = ['png', 'jpg', 'jpeg', 'bmp']
@@ -89,6 +90,14 @@ def to_gray_image(img):
         raise RuntimeError(f"unknown data type {type(img)}")
 
 
+def median_transfer(image, gray=False, target_median=120):
+    if gray:
+        image = to_gray_image(image)
+    median = max(1, np.median(image))
+    mapped_image = (np.clip(image * (target_median / median), 0, 255)).astype('uint8')
+    return mapped_image
+
+
 def to_colorful_image(image):
     """
     make a gray image to an image with 3 channels
@@ -764,11 +773,17 @@ def apply_gimp_brightness_contrast(input_img, brightness = 0, contrast = 0):
 
     return buf
 
-def connected_filter(image, min_area=0, w_h_ratio=None):
+def connected_filter(image, min_area=0, w_h_ratio=None, largest_num=None):
     image = to_gray_image(image)
     image = (image != 0).astype('uint8')
     num, mark_img, info, _ = cv2.connectedComponentsWithStats(image)
-    index_array = np.nonzero(info[:, -1] > min_area)[0]
+    if largest_num is not None:
+        largest_num = max(0, min(vvd_round(largest_num), num - 1))
+        pixel_array = info[:, -1][1:]
+        index_array, _ = get_Several_MinMax_Array(pixel_array, -largest_num)
+        index_array += 1
+    else:
+        index_array = np.nonzero(info[:, -1] > min_area)[0]
     ratio_check = False
     if w_h_ratio is not None:
         min_ratio = np.min(w_h_ratio)
