@@ -38,6 +38,7 @@ import platform
 import hashlib
 import pickle
 import uuid
+import math
 import shutil
 
 from tqdm import tqdm
@@ -1111,7 +1112,60 @@ def remove_chinese_for_file_names(root_dir):
     pass
 
 
+def get_file_time(file_path):
+    atime = os.path.getatime(file_path)  # 文件访问时间
+    mtime = os.path.getmtime(file_path)  # 文件最近修改时间
+    ctime = os.path.getctime(file_path)  # 文件的创建时间
+
+    time_info = dict(
+        access_time=atime,
+        modify_time=mtime,
+        create_time=ctime
+    )
+
+    return time_info
+
+
+def cartesian_to_polar(point_xy, center_xy, reverse_y=True):
+    x, y = point_xy
+    center_x, center_y = center_xy
+    r = cal_distance(point_xy, center_xy)
+    if r == 0:
+        theta = 0
+    elif r > 0:
+        y_ = y - center_y
+        if reverse_y:
+            y_ = - y_
+        x_ = x - center_x
+        theta = math.asin(abs(y_) / max(1, abs(r)))
+        if y_ >= 0 and x_ >= 0:
+            pass
+        elif y_ >= 0 and x_ < 0:
+            theta = np.pi - theta
+        elif y_ < 0 and x_ < 0:
+            theta = np.pi + theta
+        elif y_ < 0 and x_ >= 0:
+            theta = 2 * np.pi - theta
+        else:
+            raise RuntimeError(f'bad y_ {y_} x_ {x_}')
+    else:
+        raise RuntimeError(f'bad distance {r}')
+    return r, theta
+
+def polar_to_cartesian(r, theta, center_xy, reverse_y=True):
+    center_x, center_y = center_xy
+    if reverse_y:
+        y = center_y - r * math.sin(theta)
+    else:
+        y = center_y + r * math.sin(theta)
+    x = center_x + r * math.cos(theta)
+
+    point_xy = [x, y]
+    return point_xy
+
+
 if __name__ == '__main__':
+    print(cartesian_to_polar([-1, 1], [0,0]))
     print(chinese_str_to_pinyin('asdfd_（阿斯蒂芬）'))
     
     is_valid_identifier('')
